var group__PkgBGLIOFct =
[
    [ "STL I/O Functions", "group__PkgBGLIoFuncsSTL.html", "group__PkgBGLIoFuncsSTL" ],
    [ "PLY I/O Functions", "group__PkgBGLIoFuncsPLY.html", "group__PkgBGLIoFuncsPLY" ],
    [ "OBJ I/O Functions", "group__PkgBGLIoFuncsOBJ.html", "group__PkgBGLIoFuncsOBJ" ],
    [ "OFF I/O Functions", "group__PkgBGLIoFuncsOFF.html", "group__PkgBGLIoFuncsOFF" ],
    [ "VTP I/O Functions", "group__PkgBGLIoFuncsVTP.html", "group__PkgBGLIoFuncsVTP" ],
    [ "GOCAD I/O Functions", "group__PkgBGLIoFuncsGOCAD.html", "group__PkgBGLIoFuncsGOCAD" ],
    [ "WRL I/O Functions", "group__PkgBGLIoFuncsWRL.html", "group__PkgBGLIoFuncsWRL" ],
    [ "3MF I/O Functions", "group__PkgBGLIoFuncs3MF.html", "group__PkgBGLIoFuncs3MF" ],
    [ "I/O Functions (Deprecated)", "group__PkgBGLIOFctDeprecated.html", "group__PkgBGLIOFctDeprecated" ],
    [ "CGAL::IO::read_polygon_mesh", "group__PkgBGLIOFct.html#ga49f5b5e6fbfcbfaaac7604c88e10915c", null ],
    [ "CGAL::IO::write_polygon_mesh", "group__PkgBGLIOFct.html#gafa143949a33371dc6df8307be1ab8a66", null ]
];